# UserRequestInfoStatus

The status information for a user request

## Properties
Name | Type | Description | Notes
------------ | ------------- | ------------- | -------------
**email** | **str** | User&#39;s email address | [optional] 
**challenge_id** | **str** | The unique ID of a challenge associated with this request. It tracks approval of the request. The user may poll it to determine whether the request was approved or rejected.  | [optional] 
**expired** | **bool** | Whether or not this request has expired | [optional] 
**any string name** | **bool, date, datetime, dict, float, int, list, str, none_type** | any string name can be used but the value must be the correct type | [optional]

[[Back to Model list]](../README.md#documentation-for-models) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to README]](../README.md)


